@@ -333,7 +333,7 @@ bool kpDocument::savePixmapToFile (const QImage &pixmap,
                   "Do you want to overwrite it?",
                   kpUrlFormatter::PrettyFilename (url)),
             QString(),
-            KGuiItem(i18n ("Overwrite")));
+            KStandardGuiItem::overwrite ());
 
         if (result != KMessageBox::Continue)
         {
