@@ -36,7 +36,7 @@
 #include <QDragMoveEvent>
 
 #include <KColorMimeData>
-#include <kdebug.h>
+#include "kpLogCategories.h"
 #include <klocale.h>
 
 #include "widgets/kpColorCells.h"
@@ -111,7 +111,7 @@ kpColorToolBar::kpColorToolBar (const QString &label, QWidget *parent)
 void kpColorToolBar::adjustToOrientation (Qt::Orientation o)
 {
 #if DEBUG_KP_COLOR_TOOL_BAR
-    kDebug () << "kpColorToolBar::adjustToOrientation("
+    qCDebug(kpLogWidgets) << "kpColorToolBar::adjustToOrientation("
                << (o == Qt::Vertical ? "vertical" : "horizontal")
                << ") called!";
 #endif
@@ -168,7 +168,7 @@ kpColor kpColorToolBar::foregroundColor () const
 void kpColorToolBar::setForegroundColor (const kpColor &color)
 {
 #if DEBUG_KP_COLOR_TOOL_BAR
-    kDebug () << "kpColorToolBar::setForegroundColor("
+    qCDebug(kpLogWidgets) << "kpColorToolBar::setForegroundColor("
               << (int *) color.toQRgb () << ")" << endl;
 #endif
     m_dualColorButton->setForegroundColor (color);
@@ -186,7 +186,7 @@ kpColor kpColorToolBar::backgroundColor () const
 void kpColorToolBar::setBackgroundColor (const kpColor &color)
 {
 #if DEBUG_KP_COLOR_TOOL_BAR
-    kDebug () << "kpColorToolBar::setBackgroundColor("
+    qCDebug(kpLogWidgets) << "kpColorToolBar::setBackgroundColor("
               << (int *) color.toQRgb () << ")" << endl;
 #endif
     m_dualColorButton->setBackgroundColor (color);
@@ -308,7 +308,7 @@ void kpColorToolBar::dragEnterEvent (QDragEnterEvent *e)
     // handled by our parent, the main window.
     e->setAccepted (KColorMimeData::canDecode (e->mimeData ()) == true);
 #if DEBUG_KP_COLOR_TOOL_BAR
-    kDebug () << "isAccepted=" << e->isAccepted ();
+    qCDebug(kpLogWidgets) << "isAccepted=" << e->isAccepted ();
 #endif
 }
 
@@ -320,7 +320,7 @@ void kpColorToolBar::dragMoveEvent (QDragMoveEvent *e)
     // Stop the grabbed drag from being dropped.
     e->setAccepted (KColorMimeData::canDecode (e->mimeData ()) == false);
 #if DEBUG_KP_COLOR_TOOL_BAR
-    kDebug () << "isAccepted=" << e->isAccepted ();
+    qCDebug(kpLogWidgets) << "isAccepted=" << e->isAccepted ();
 #endif
 }
 
